# 2021-12-08 - Aave Linear Pool

> ⚠️ **DEPRECATED: do not use** ⚠️
>
> This factory and associated Pools were superseded by this [updated version (also now deprecated)](../20220817-aave-rebalanced-linear-pool), which featured a permissionless Rebalancer with Asset Manager privileges.

Deployment of the `AaveLinearPoolFactory`, for Linear Pools with a wrapped aToken.

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [Polygon mainnet addresses](./output/polygon.json)
- [Arbitrum mainnet address](./output/arbitrum.json)
- [Goerli testnet addresses](./output/goerli.json)
- [`AaveLinearPoolFactory` artifact](./artifact/AaveLinearPoolFactory.json)
